@@ -36,7 +36,7 @@ public:
     virtual AbstractAccountUi* accountUi(const QString &connectionManager, const QString &protocol, const QString &serviceName);
 
 private:
-    Q_DISABLE_COPY(GabbleAccountUiPlugin);
+    Q_DISABLE_COPY(GabbleAccountUiPlugin)
 };
 
 
